Take me over?
The maintainer of this distribution is looking for someone to take over!
If you're interested then please contact them via
email.
NAME
PDFLib - More OO interface to pdflib_pl.pm
SYNOPSIS
use PDFLib;
my $pdf = PDFLib->new("foo.pdf");
DESCRIPTION
A cleaner API than pdflib_pl.pm, which is a very low-level (non-OO) interface.
AUTHOR
AxKit.com Ltd,
Matt Sergeant, matt@axkit.com
LICENSE
This is free software. You may distribute it under the same terms as Perl itself.